@@ -20,13 +20,16 @@ textModels <- function(){
   return(models)
 }
 
-#' Get the number of layers in a given model.
+#' Number of layers
+#'
+#' This functions gets the number of layers in a given model.
 #' @param target_model (string) The name of the model to know the number of layers of.
 #' @param hg_gated Set to TRUE if the accessed model is gated.
 #' @param hg_token The token needed to access the gated model.
 #' Create a token from the ['Settings' page](https://huggingface.co/settings/tokens) of
 #' the Hugging Face website. An an environment variable HUGGINGFACE_TOKEN can
 #' be set to avoid the need to enter the token each time.
+#' @param trust_remote_code use a model with custom code on the Huggingface Hub
 #' @return Number of layers.
 #' @examples
 #' \dontrun{
@@ -38,7 +41,8 @@ textModels <- function(){
 textModelLayers <- function(target_model,
                             hg_gated = FALSE,
                             hg_token = Sys.getenv("HUGGINGFACE_TOKEN",
-                                                  unset = "")){
+                                                  unset = ""),
+                            trust_remote_code = FALSE){
   reticulate::source_python(system.file("python",
     "huggingface_Interface3.py",
     package = "text",
@@ -48,14 +52,17 @@ textModelLayers <- function(target_model,
   n_layer <- get_number_of_hidden_layers(target_model,
     logging_level = "error",
     hg_gated = reticulate::r_to_py(hg_gated),
-    hg_token = reticulate::r_to_py(hg_token)
+    hg_token = reticulate::r_to_py(hg_token),
+    trust_remote_code = trust_remote_code
   )
 
   return(n_layer)
 }
 
 
-#' Delete a specified model and model associated files.
+#' Delete a specified model
+#'
+#' This functions delete specified mode and associated files.
 #' @param target_model (string) The name of the model to be deleted.
 #' @return Confirmation whether the model has been deleted.
 #' @examples
