@@ -7,7 +7,7 @@
 #' @param tokenizer_parallelism (boolean)  If TRUE this will turn on tokenizer parallelism.
 #' @param logging_level (string)  Set the logging level.
 #' Options (ordered from less logging to more logging): critical, error, warning, info, debug
-#' @param return_incorrect_results (boolean)  Stop returning some incorrectly formatted/structured results.
+#' @param force_return_results (boolean)  Stop returning some incorrectly formatted/structured results.
 #' This setting does CANOT evaluate the actual results (whether or not they make sense, exist, etc.).
 #' All it does is to ensure the returned results are formatted correctly (e.g., does the question-answering
 #' dictionary contain the key "answer", is sentiments from textClassify containing the labels "positive"
@@ -30,7 +30,7 @@ textNER <- function(x,
                     device = "cpu",
                     tokenizer_parallelism = FALSE,
                     logging_level = "error",
-                    return_incorrect_results = FALSE,
+                    force_return_results = FALSE,
                     set_seed = 202208L) {
   T1_text_all <- Sys.time()
 
@@ -55,7 +55,7 @@ textNER <- function(x,
       device = device,
       tokenizer_parallelism = tokenizer_parallelism,
       logging_level = logging_level,
-      return_incorrect_results = return_incorrect_results,
+      force_return_results = force_return_results,
       set_seed = set_seed
     )
 
@@ -88,7 +88,7 @@ textNER <- function(x,
       sep = " "
     )
 
-    cat(colourise(loop_text, "green"))
+    message(colourise(loop_text, "green"))
   }
 
   names(ALL_output) <- paste0(names(data_character_variables), "_NER")
