@@ -1,3 +1,5 @@
+
+
 #' Question Answering. (experimental)
 #' @param question (string)  A question
 #' @param context (string)  The context(s) where the model will look for the answer.
@@ -7,7 +9,7 @@
 #' @param tokenizer_parallelism (boolean)  If TRUE this will turn on tokenizer parallelism.
 #' @param logging_level (string)  Set the logging level.
 #' Options (ordered from less logging to more logging): critical, error, warning, info, debug
-#' @param return_incorrect_results (boolean)  Stop returning some incorrectly formatted/structured results.
+#' @param force_return_results (boolean)  Stop returning some incorrectly formatted/structured results.
 #' This setting does CANOT evaluate the actual results (whether or not they make sense, exist, etc.).
 #' All it does is to ensure the returned results are formatted correctly (e.g., does the question-answering
 #' dictionary contain the key "answer", is sentiments from textClassify containing the labels "positive"
@@ -38,7 +40,7 @@ textQA <- function(question,
                    device = "cpu",
                    tokenizer_parallelism = FALSE,
                    logging_level = "warning",
-                   return_incorrect_results = FALSE,
+                   force_return_results = FALSE,
                    top_k = 1L,
                    doc_stride = 128L,
                    max_answer_len = 15L,
@@ -67,7 +69,7 @@ textQA <- function(question,
       device = device,
       tokenizer_parallelism = tokenizer_parallelism,
       logging_level = logging_level,
-      return_incorrect_results = return_incorrect_results,
+      force_return_results = force_return_results,
       top_k = top_k,
       doc_stride = doc_stride,
       max_answer_len = max_answer_len,
@@ -75,7 +77,7 @@ textQA <- function(question,
       max_question_len = max_question_len,
       handle_impossible_answer = handle_impossible_answer,
       set_seed = set_seed
-    )[[1]]
+    )#[[1]]
 
     output1 <- dplyr::bind_rows(hg_QA)
 
@@ -95,7 +97,7 @@ textQA <- function(question,
       sep = " "
     )
 
-    cat(colourise(loop_text, "green"))
+    message(colourise(loop_text, "green"))
   }
 
   ALL_output <- dplyr::bind_rows(ALL_output)
